@@ -86,6 +86,7 @@ gnc_euro_rate_compare (const void * key, const void * value)
     return g_ascii_strcasecmp(gnc_commodity_get_mnemonic(curr), euro->currency);
 }
 
+#if 0 /* Not Used */
 static int
 gnc_euro_rate_compare_code (const void * key, const void * value)
 {
@@ -97,25 +98,10 @@ gnc_euro_rate_compare_code (const void * key, const void * value)
 
     return g_ascii_strcasecmp (code, euro->currency);
 }
+#endif
 
 /* ------------------------------------------------------ */
 
-gboolean
-gnc_is_euro_currency_code (const char *code)
-{
-    gnc_euro_rate_struct *result;
-
-    if (!code) return FALSE;
-
-    result = bsearch (code,
-                      gnc_euro_rates,
-                      sizeof(gnc_euro_rates) / sizeof(gnc_euro_rate_struct),
-                      sizeof(gnc_euro_rate_struct),
-                      gnc_euro_rate_compare_code);
-
-    return result != NULL;
-}
-
 gboolean
 gnc_is_euro_currency(const gnc_commodity * currency)
 {
