@@ -1198,7 +1198,7 @@ create_each_transaction_helper(Transaction *template_txn, void *user_data)
 
 
                 g_debug("amount is %s for memo split '%s'", gnc_numeric_to_string (amt), xaccSplitGetMemo (copying_split));
-                xaccSplitSetAmount(copying_split, amt);
+                xaccSplitSetAmount(copying_split, amt); /* marks split dirty */
             }
 
             xaccSplitScrub(copying_split);
@@ -1217,7 +1217,11 @@ create_each_transaction_helper(Transaction *template_txn, void *user_data)
     {
         kvp_frame *txn_frame;
         txn_frame = xaccTransGetSlots(new_txn);
-        kvp_frame_set_guid(txn_frame, "from-sched-xaction", xaccSchedXactionGetGUID(creation_data->instance->parent->sx));
+        kvp_frame_set_guid(txn_frame, "from-sched-xaction",
+		  xaccSchedXactionGetGUID(creation_data->instance->parent->sx));
+/* The transaction was probably marked dirty by xaccTransSetCurrency,
+ * but just in case: */
+	qof_instance_set_dirty (QOF_INSTANCE (new_txn));
     }
 
     xaccTransCommitEdit(new_txn);
