@@ -23,7 +23,7 @@ test_query (Query *q, SCM val2str)
     args = scm_cons (scm_q, SCM_EOL);
     str_q = scm_apply (val2str, args, SCM_EOL);
 
-    args = scm_cons (scm_from_locale_string ("'"), scm_cons (str_q, SCM_EOL));
+    args = scm_cons (scm_from_utf8_string ("'"), scm_cons (str_q, SCM_EOL));
     str_q = scm_string_append (args);
 
     scm_display (str_q, SCM_UNDEFINED);
