@@ -43,7 +43,7 @@
 
 #define _GNC_MOD_NAME	GNC_ID_JOB
 
-static QofLogModule log_module = G_LOG_DOMAIN;
+G_GNUC_UNUSED static QofLogModule log_module = G_LOG_DOMAIN;
 
 #define TABLE_NAME "jobs"
 #define TABLE_VERSION 1
@@ -79,10 +79,10 @@ load_single_job( GncSqlBackend* be, GncSqlRow* row )
     g_return_val_if_fail( row != NULL, NULL );
 
     guid = gnc_sql_load_guid( be, row );
-    pJob = gncJobLookup( be->primary_book, guid );
+    pJob = gncJobLookup( be->book, guid );
     if ( pJob == NULL )
     {
-        pJob = gncJobCreate( be->primary_book );
+        pJob = gncJobCreate( be->book );
     }
     gnc_sql_load_object( be, row, GNC_ID_JOB, pJob, col_table );
     qof_instance_mark_clean( QOF_INSTANCE(pJob) );
@@ -95,12 +95,9 @@ load_all_jobs( GncSqlBackend* be )
 {
     GncSqlStatement* stmt;
     GncSqlResult* result;
-    QofBook* pBook;
 
     g_return_if_fail( be != NULL );
 
-    pBook = be->primary_book;
-
     stmt = gnc_sql_create_select_statement( be, TABLE_NAME );
     result = gnc_sql_execute_select_statement( be, stmt );
     gnc_sql_statement_dispose( stmt );
@@ -197,7 +194,7 @@ write_jobs( GncSqlBackend* be )
 
     data.be = be;
     data.is_ok = TRUE;
-    qof_object_foreach( GNC_ID_JOB, be->primary_book, write_single_job, &data );
+    qof_object_foreach( GNC_ID_JOB, be->book, write_single_job, &data );
 
     return data.is_ok;
 }
