@@ -584,21 +584,21 @@ gnc_date_string_to_timespec_gmt (gchar *datestr)
     GDateTime *dt = NULL;
 
     sscanf (datestr, "%04d-%02d-%02d %02d:%02d:%02lf",
-	    &yr, &mo, &da, &hr, &min, &sec);
+            &yr, &mo, &da, &hr, &min, &sec);
     g_assert_cmpint (1, <=, yr);
     g_assert_cmpint (9999, >=, yr);
     g_assert_cmpint (1, <=, mo);
     g_assert_cmpint (12, >=, mo);
     g_assert_cmpint (1, <=, da);
     if (mo == 1 || mo == 3 || mo == 5 || mo == 7
-	|| mo == 8 || mo == 10 || mo == 12)
-	g_assert_cmpint (31, >=, da);
+            || mo == 8 || mo == 10 || mo == 12)
+        g_assert_cmpint (31, >=, da);
     else if (mo != 2)
-	g_assert_cmpint (30, >=, da);
+        g_assert_cmpint (30, >=, da);
     else if (yr % 4 == 0 && !(yr % 400 == 0 && yr % 2000 != 0))
-	g_assert_cmpint (29, >=, da);
+        g_assert_cmpint (29, >=, da);
     else
-	g_assert_cmpint (28, >=, da);
+        g_assert_cmpint (28, >=, da);
     g_assert_cmpint (0, <=, hr);
     g_assert_cmpint (60, >=, hr);
     g_assert_cmpint (0, <=, min);
@@ -616,27 +616,31 @@ gnc_date_string_to_timespec_gmt (gchar *datestr)
 static void
 test_gnc_sql_convert_timespec_to_string ()
 {
-    GncSqlBackend be = {{NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
-			 NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
-			 0, NULL, 0, "", NULL, 0, "", NULL, NULL},
-			NULL, NULL, FALSE, FALSE, FALSE, 0, 0, NULL,
-			"%4d-%02d-%02d %02d:%02d:%02d"};
+    GncSqlBackend be = {{
+            NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
+            NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
+            0, NULL, 0, "", NULL, 0, "", NULL, NULL
+        },
+        NULL, NULL, FALSE, FALSE, FALSE, 0, 0, NULL,
+        "%4d-%02d-%02d %02d:%02d:%02d"
+    };
     gchar *date[numtests] = {"1995-03-11 19:17:26",
-			     "2001-04-20 11:44:07",
-			     "1964-02-29 09:15:23",
-			     "1959-04-02 00:00:00",
-			     "2043-11-22 05:32:45",
-			     "2153-12-18 01:15:30"};
+                             "2001-04-20 11:44:07",
+                             "1964-02-29 09:15:23",
+                             "1959-04-02 00:00:00",
+                             "2043-11-22 05:32:45",
+                             "2153-12-18 01:15:30"
+                            };
     int i;
     for (i = 0; i < numtests; i++)
     {
 
-	Timespec *ts = gnc_date_string_to_timespec_gmt (date[i]);
-	gchar *datestr = gnc_sql_convert_timespec_to_string (&be, *ts);
-	g_assert_cmpstr (date[i], ==, datestr);
+        Timespec *ts = gnc_date_string_to_timespec_gmt (date[i]);
+        gchar *datestr = gnc_sql_convert_timespec_to_string (&be, *ts);
+        g_assert_cmpstr (date[i], ==, datestr);
 
-	g_free (datestr);
-	g_slice_free (Timespec, ts);
+        g_free (datestr);
+        g_slice_free (Timespec, ts);
     }
 
 }
