@@ -282,14 +282,11 @@ gnc_order_end_handler(gpointer data_for_children,
                       gpointer parent_data, gpointer global_data,
                       gpointer *result, const gchar *tag)
 {
-    int successful;
     GncOrder *order;
     xmlNodePtr tree = (xmlNodePtr)data_for_children;
     gxpf_data *gdata = (gxpf_data*)global_data;
     QofBook *book = gdata->bookdata;
 
-    successful = TRUE;
-
     if (parent_data)
     {
         return TRUE;
