@@ -41,6 +41,9 @@
 #include "io-gncxml-gen.h"
 #include "sixtp-utils.h"
 
+/*
+#define __DEBUG 1
+*/
 /***********************************************************************/
 
 static int
@@ -388,7 +391,7 @@ test_files_in_dir(int argc, char **argv, gxpf_callback cb,
         {
             if (!S_ISDIR(file_info.st_mode))
             {
-#if 0
+#ifdef __DEBUG
                 printf( "testing load of file \"%s\":\n", argv[count] );
 #endif
                 test_load_file(to_open, cb, top_parser, book);
