@@ -14,7 +14,9 @@ for i in $SRCDIR/test-files/xml2/*.gml2 ; do
       mkdir $j
       FILES=`perl $SRCDIR/grab-types.pl "gnc:$j" $i "$j/dataXXX.xml"`
       if [ ! -z "$FILES" ] ; then
-        echo "Testing ./test-xml-$j $j/data*.xml # from `basename $i`:" 
+	  if [ "x$VERBOSE" = "xyes" ] ; then
+              echo "Testing ./test-xml-$j $j/data*.xml # from `basename $i`:"
+	  fi
         eval "./test-xml-$j $FILES 2>/dev/null"
         if [ $? != 0 ] ; then
           EXIT_VALUE=1
