@@ -35,6 +35,7 @@
 #include "gnc-locale-utils.h"
 #include "core-utils/gnc-version.h"
 #include "gnc-engine.h"
+#include "gnc-environment.h"
 #include "gnc-filepath-utils.h"
 #include "gnc-ui-util.h"
 #include "gnc-file.h"
@@ -42,12 +43,13 @@
 #include "top-level.h"
 #include "gfec.h"
 #include "gnc-commodity.h"
-#include "gnc-core-prefs.h"
+#include "gnc-prefs.h"
+#include "gnc-prefs-utils.h"
+#include "gnc-gsettings.h"
 #include "gnc-main-window.h"
 #include "gnc-splash.h"
 #include "gnc-gnome-utils.h"
 #include "gnc-plugin-file-history.h"
-#include "gnc-gconf-utils.h"
 #include "dialog-new-user.h"
 #include "gnc-session.h"
 #include "engine-helpers-guile.h"
@@ -70,7 +72,7 @@ static QofLogModule log_module = GNC_MOD_GUI;
 static int is_development_version = TRUE;
 #else
 static int is_development_version = FALSE;
-#define GNUCASH_SCM 0
+#define GNUCASH_SCM ""
 #endif
 
 /* Command-line option variables */
@@ -80,7 +82,7 @@ static int          extra            = 0;
 static gchar      **log_flags        = NULL;
 static gchar       *log_to_filename  = NULL;
 static int          nofile           = 0;
-static const gchar *gconf_path       = NULL;
+static const gchar *gsettings_prefix = NULL;
 static const char  *add_quotes_file  = NULL;
 static char        *namespace_regexp = NULL;
 static const char  *file_to_load     = NULL;
@@ -120,11 +122,11 @@ static GOptionEntry options[] =
         N_("Do not load the last file opened"), NULL
     },
     {
-        "gconf-path", '\0', 0, G_OPTION_ARG_STRING, &gconf_path,
-        N_("Set the prefix path for gconf queries"),
+        "gsettings-prefix", '\0', 0, G_OPTION_ARG_STRING, &gsettings_prefix,
+        N_("Set the prefix for gsettings schemas for gsettings queries. This can be useful to have a different settings tree while debugging."),
         /* Translators: Argument description for autohelp; see
            http://developer.gnome.org/doc/API/2.0/glib/glib-Commandline-option-parser.html */
-        N_("GCONFPATH")
+        N_("GSETTINGSPREFIX")
     },
     {
         "add-price-quotes", '\0', 0, G_OPTION_ARG_STRING, &add_quotes_file,
@@ -157,183 +159,7 @@ gnc_print_unstable_message(void)
             _("To find the last stable version, please refer to http://www.gnucash.org"));
 }
 
-#ifndef MAC_INTEGRATION
-static gchar  *environment_expand(gchar *param)
-{
-    gchar *search_start;
-    gchar *opening_brace;
-    gchar *closing_brace;
-    gchar *result;
-    gchar *tmp;
-    gchar *expanded = NULL;
-
-    if (!param)
-        return NULL;
-
-    /* Set an initial return value, so we can always use g_strconcat below) */
-    result = g_strdup ("x");
-
-    /* Look for matching pairs of { and }. Anything in between should be expanded */
-    search_start = param;
-    opening_brace = g_strstr_len (search_start, -1, "{");
-    closing_brace = g_strstr_len (search_start, -1, "}");
-
-    /* Note: the test on valid braces is fairly simple:
-     *       * if no pair of opening/closing braces is found, no expansion occurs
-     *       * braces can't be nested, this will give unexpected results
-     *       * the string should contain no other braces than those used to mark
-     *         expandable variables, or unexpected results will be returned.
-     */
-    while ( opening_brace && closing_brace && (closing_brace > opening_brace) )
-    {
-        /* Found a first matching pair */
-        gchar *to_expand;
-        const gchar *env_val;
-
-        /* If the string had characters before the opening {, copy them first */
-        if (opening_brace > search_start)
-        {
-            gchar *prefix = g_strndup (search_start, opening_brace - search_start);
-
-            tmp = g_strconcat (result, prefix, NULL);
-            g_free (result);
-            result = tmp;
-            g_free (prefix);
-        }
-
-        /* Expand the variable  we found and append it to the result */
-        to_expand = g_strndup (opening_brace + 1, closing_brace - opening_brace - 1);
-        env_val = g_getenv (to_expand);
-        tmp = g_strconcat (result, env_val, NULL);
-        g_free (result);
-        result = tmp;
-        g_free (to_expand);
-
-        /* Look for matching pairs of { and }. Anything in between should be expanded */
-        search_start = closing_brace + 1;
-        opening_brace = g_strstr_len (search_start, -1, "{");
-        closing_brace = g_strstr_len (search_start, -1, "}");
-    }
-
-    /* No more braces found, append the remaining characters */
-    tmp = g_strconcat (result, search_start, NULL);
-    g_free (result);
-    result = tmp;
-
-    /* Remove the "x" from our result */
-    if (g_strcmp0 (result, "x"))
-        expanded = g_strdup (result + 1);
-    g_free (result);
-
-    return expanded;
-}
-
-static void
-environment_override()
-{
-    gchar *config_path;
-    gchar *env_file;
-    GKeyFile    *keyfile = g_key_file_new();
-    GError      *error;
-    gchar **env_vars;
-    gsize param_count;
-    gint i;
-    gboolean got_keyfile;
-    gchar *env_parm, *bin_parm;
-
-    /* Export default parameters to the environment */
-    env_parm = gnc_path_get_prefix();
-    if (!g_setenv("GNC_HOME", env_parm, FALSE))
-        g_warning ("Couldn't set/override environment variable GNC_HOME.");
-    bin_parm = g_build_filename(env_parm, "bin", NULL);
-    if (!g_setenv("GNC_BIN", bin_parm, FALSE))
-        g_warning ("Couldn't set/override environment variable GNC_BIN.");
-    g_free (env_parm);
-    g_free (bin_parm);
-    env_parm = gnc_path_get_pkglibdir();
-    if (!g_setenv("GNC_LIB", env_parm, FALSE))
-        g_warning ("Couldn't set/override environment variable GNC_LIB.");
-    g_free (env_parm);
-    env_parm = gnc_path_get_pkgdatadir();
-    if (!g_setenv("GNC_DATA", env_parm, FALSE))
-        g_warning ("Couldn't set/override environment variable GNC_DATA.");
-    g_free (env_parm);
-    env_parm = gnc_path_get_pkgsysconfdir();
-    if (!g_setenv("GNC_CONF", env_parm, FALSE))
-        g_warning ("Couldn't set/override environment variable GNC_CONF.");
-    g_free (env_parm);
-    env_parm = gnc_path_get_libdir();
-    if (!g_setenv("SYS_LIB", env_parm, FALSE))
-        g_warning ("Couldn't set/override environment variable SYS_LIB.");
-    g_free (env_parm);
-
-    config_path = gnc_path_get_pkgsysconfdir();
-#ifdef G_OS_WIN32
-    {
-        /* unhide files without extension */
-        gchar *pathext = g_build_path(";", ".", g_getenv("PATHEXT"),
-                                      (gchar*) NULL);
-        g_setenv("PATHEXT", pathext, TRUE);
-        g_free(pathext);
-    }
-#endif
-
-    env_file = g_build_filename (config_path, "environment", NULL);
-    got_keyfile = g_key_file_load_from_file (keyfile, env_file, G_KEY_FILE_NONE, &error);
-    g_free (config_path);
-    g_free (env_file);
-    if ( !got_keyfile )
-    {
-        g_key_file_free(keyfile);
-        return;
-    }
-
-    /* Read the environment overrides and apply them */
-    env_vars = g_key_file_get_keys(keyfile, "Variables", &param_count, &error);
-    for ( i = 0; i < param_count; i++ )
-    {
-        gchar **val_list;
-        gsize val_count;
-        gint j;
-        gchar *new_val = NULL, *tmp_val;
-
-        /* For each variable, read its new value, optionally expand it and set/unset it */
-        val_list = g_key_file_get_string_list (keyfile, "Variables",
-                                               env_vars[i], &val_count,
-                                               &error );
-        if ( val_count == 0 )
-            g_unsetenv (env_vars[i]);
-        else
-        {
-            /* Set an initial return value, so we can always use g_build_path below) */
-            tmp_val = g_strdup ("x");
-            for ( j = 0; j < val_count; j++ )
-            {
-                gchar *expanded = environment_expand (val_list[j]);
-                new_val = g_build_path (G_SEARCHPATH_SEPARATOR_S, tmp_val, expanded, NULL);
-                g_free (tmp_val);
-                g_free(expanded);
-                tmp_val = new_val;
-            }
-            g_strfreev (val_list);
-
-            /* Remove the "x" from our result */
-            if (g_strcmp0 (tmp_val, "x"))
-                new_val = g_strdup (tmp_val + sizeof (G_SEARCHPATH_SEPARATOR_S));
-            g_free (tmp_val);
-
-            if (!g_setenv (env_vars[i], new_val, TRUE))
-                g_warning ("Couldn't properly override environment variable \"%s\". "
-                           "This may lead to unexpected results", env_vars[i]);
-            g_free(new_val);
-        }
-    }
-
-    g_strfreev(env_vars);
-    g_key_file_free(keyfile);
-}
-
-#else /* MAC_INTEGRATION */
+#ifdef MAC_INTEGRATION
 static void
 set_mac_locale()
 {
@@ -362,7 +188,32 @@ set_mac_locale()
     if ([locale_str isEqualToString: @"_"])
 	locale_str = @"en_US";
 
-    setlocale(LC_ALL, [locale_str UTF8String]);
+    if (!setlocale(LC_ALL, [locale_str UTF8String]))
+    {
+	NSArray *all_locales = [NSLocale availableLocaleIdentifiers];
+	NSEnumerator *locale_iter = [all_locales objectEnumerator];
+	NSString *this_locale, *new_locale = nil;
+	NSString *lang = [locale objectForKey: NSLocaleLanguageCode];
+	PWARN("Apple Locale is set to a value %s not supported"
+	      " by the C runtime", [locale_str UTF8String]);
+	while ((this_locale = (NSString*)[locale_iter nextObject]))
+	    if ([[[NSLocale componentsFromLocaleIdentifier: this_locale]
+		  objectForKey: NSLocaleLanguageCode]
+		 isEqualToString: lang] &&
+		setlocale (LC_ALL, [this_locale UTF8String]))
+	    {
+		new_locale = this_locale;
+		break;
+	    }
+	if (new_locale)
+	    locale_str = new_locale;
+	else
+	{
+	    locale_str = @"en_US";
+	    setlocale(LC_ALL, [locale_str UTF8String]);
+	}
+	PWARN("Using %s instead.", [locale_str UTF8String]);
+    }
     if (g_getenv("LANG") == NULL)
 	g_setenv("LANG", [locale_str UTF8String], TRUE);
 /* If the currency doesn't match the base locale, we need to find a locale that does match, because setlocale won't know what to do with just a currency identifier. */
@@ -374,12 +225,18 @@ set_mac_locale()
 	NSString *currency = [locale objectForKey: NSLocaleCurrencyCode];
 	NSString *money_locale = nil;
 	while ((this_locale = (NSString*)[locale_iter nextObject]))
-	    if ([[[[NSLocale alloc] initWithLocaleIdentifier: this_locale]
-		   objectForKey: NSLocaleCurrencyCode]
-		 isEqualToString: currency]) {
+	{
+	    NSLocale *templocale = [[NSLocale alloc]
+				    initWithLocaleIdentifier: this_locale];
+	    if ([[templocale objectForKey: NSLocaleCurrencyCode]
+		 isEqualToString: currency])
+	    {
 		money_locale = this_locale;
+		[templocale release];
 		break;
 	    }
+	    [templocale release];
+	}
 	if (money_locale)
 	    setlocale(LC_MONETARY, [money_locale UTF8String]);
     }
@@ -408,9 +265,9 @@ set_mac_locale()
 	    if ([elements count] > 1) {
 		if ([[elements objectAtIndex: 0] isEqualToString: @"zh"]) {
 		    if ([[elements objectAtIndex: 1] isEqualToString: @"Hans"])
-			this_lang = [NSString stringWithString: @"zh_CN"];
+			this_lang = @"zh_CN";
 		    else
-			this_lang = [NSString stringWithString: @"zh_TW"];
+			this_lang = @"zh_TW";
 		}
 		else
 		  this_lang = [elements componentsJoinedByString: @"_"];
@@ -562,21 +419,14 @@ gnc_parse_command_line(int *argc, char ***argv)
         exit(0);
     }
 
-    gnc_core_prefs_set_debugging(debugging);
-    gnc_core_prefs_set_extra(extra);
+    gnc_prefs_set_debugging(debugging);
+    gnc_prefs_set_extra(extra);
 
-    if (!gconf_path)
-    {
-        const char *path = g_getenv("GNC_GCONF_PATH");
-        if (path)
-            gconf_path = path;
-        else
-            gconf_path = GCONF_PATH;
-    }
-    gnc_gconf_set_path_prefix(g_strdup(gconf_path));
+    if (gsettings_prefix)
+        gnc_gsettings_set_prefix(g_strdup(gsettings_prefix));
 
     if (namespace_regexp)
-        gnc_core_prefs_set_namespace_regexp(namespace_regexp);
+        gnc_prefs_set_namespace_regexp(namespace_regexp);
 
     if (args_remaining)
         file_to_load = args_remaining[0];
@@ -613,6 +463,8 @@ load_gnucash_modules()
         { "gnucash/business-gnome", 0, TRUE },
         { "gnucash/gtkmm", 0, TRUE },
         { "gnucash/python", 0, TRUE },
+        { "gnucash/plugins/bi_import", 0, TRUE},
+        { "gnucash/plugins/customer_import", 0, TRUE},
     };
 
     /* module initializations go here */
@@ -654,7 +506,7 @@ inner_main_add_price_quotes(void *closure, int argc, char **argv)
 #ifdef PRICE_QUOTES_NEED_MODULES
     load_gnucash_modules();
 #endif
-
+    gnc_prefs_init ();
     qof_event_suspend();
     scm_c_eval_string("(gnc:price-quotes-install-sources)");
 
@@ -719,6 +571,10 @@ inner_main (void *closure, int argc, char **argv)
     main_mod = scm_c_resolve_module("gnucash main");
     scm_set_current_module(main_mod);
 
+    /* GnuCash switched to gsettings to store its preferences in version 2.5.6
+     * Migrate the user's preferences from gconf if needed */
+    gnc_gsettings_migrate_from_gconf();
+
     load_gnucash_modules();
 
     /* Load the config before starting up the gui. This insures that
@@ -751,8 +607,7 @@ inner_main (void *closure, int argc, char **argv)
         gnc_file_open_file(fn, /*open_readonly*/ FALSE);
         g_free(fn);
     }
-    else if (gnc_gconf_get_bool("dialogs/new_user", "first_startup", &error)
-             && !error)
+    else if (gnc_prefs_get_bool(GNC_PREFS_GROUP_NEW_USER, GNC_PREF_FIRST_STARTUP))
     {
         gnc_destroy_splash_screen();
         gnc_ui_new_user_dialog();
@@ -791,7 +646,7 @@ gnc_log_init()
 
     gnc_log_default();
 
-    if (gnc_core_prefs_is_debugging_enabled())
+    if (gnc_prefs_is_debugging_enabled())
     {
         qof_log_set_level("", QOF_LOG_INFO);
         qof_log_set_level("qof", QOF_LOG_INFO);
@@ -832,6 +687,7 @@ gnc_log_init()
 int
 main(int argc, char ** argv)
 {
+    gchar *sys_locale = NULL;
 #if !defined(G_THREADS_ENABLED) || defined(G_THREADS_IMPL_NONE)
 #    error "No GLib thread implementation available!"
 #endif
@@ -855,8 +711,17 @@ main(int argc, char ** argv)
      */
 #ifdef MAC_INTEGRATION
     set_mac_locale();
-#else
-    environment_override();
+#endif
+    gnc_environment_setup();
+#ifndef MAC_INTEGRATION /* setlocale already done */
+    sys_locale = g_strdup (setlocale (LC_ALL, ""));
+    if (!sys_locale)
+      {
+        g_print ("The locale defined in the environment isn't supported. "
+                 "Falling back to the 'C' (US English) locale\n");
+        g_setenv ("LC_ALL", "C", TRUE);
+        setlocale (LC_ALL, "C");
+      }
 #endif
 #ifdef HAVE_GETTEXT
     {
@@ -873,6 +738,15 @@ main(int argc, char ** argv)
 
     gnc_log_init();
 
+#ifndef MAC_INTEGRATION
+    /* Write some locale details to the log to simplify debugging
+     * To be on the safe side, only do this if not on OS X,
+     * to avoid unintentionally messing up the locale settings */
+    PINFO ("System locale returned %s", sys_locale ? sys_locale : "(null)");
+    PINFO ("Effective locale set to %s.", setlocale (LC_ALL, ""));
+    g_free (sys_locale);
+#endif
+
     /* If asked via a command line parameter, fetch quotes only */
     if (add_quotes_file)
     {
