@@ -33,10 +33,13 @@
 #include "gnc-gui-query.h"
 #include "gnc-ui-util.h"
 #include "qof.h"
+#include "gnc-date.h"
 #include "gnc-date-edit.h"
 #include "gnc-amount-edit.h"
 #include "gnc-gtk-utils.h"
+#include "gnc-prefs.h"
 #include "gnc-tree-view-account.h"
+#include "tree-view-utils.h"
 #include "Transaction.h"
 #include "Account.h"
 #include "gncOwner.h"
@@ -145,7 +148,7 @@ void gnc_payment_window_destroy_cb (GtkWidget *widget, gpointer data);
 void gnc_payment_acct_tree_row_activated_cb (GtkWidget *widget, GtkTreePath *path,
         GtkTreeViewColumn *column, PaymentWindow *pw);
 void gnc_payment_leave_amount_cb (GtkWidget *widget, GdkEventFocus *event,
-        PaymentWindow *pw);
+                                  PaymentWindow *pw);
 
 
 static void
@@ -286,7 +289,7 @@ gnc_payment_window_fill_docs_list (PaymentWindow *pw)
     for (node = list; node; node = node->next)
     {
         GNCLot *lot = node->data;
-        const gchar *doc_date_str = NULL;
+        time64 doc_date_time = 0;
         const gchar *doc_type_str = NULL;
         const gchar *doc_id_str   = NULL;
         const gchar *doc_deb_str  = NULL;
@@ -314,7 +317,7 @@ gnc_payment_window_fill_docs_list (PaymentWindow *pw)
             else
                 continue; /* No valid split in this lot, skip it */
         }
-        doc_date_str = gnc_print_date (doc_date);
+        doc_date_time = timespecToTime64 (doc_date);
 
         /* Find the document type. No type means pre-payment in this case */
         if (document)
@@ -350,7 +353,7 @@ gnc_payment_window_fill_docs_list (PaymentWindow *pw)
 
         gtk_list_store_append (store, &iter);
         gtk_list_store_set (store, &iter,
-                            0, doc_date_str,
+                            0, doc_date_time,
                             1, doc_id_str,
                             2, doc_type_str,
                             3, doc_deb_str,
@@ -548,8 +551,8 @@ gnc_payment_ok_cb (GtkWidget *widget, gpointer data)
     amount_deb  = gnc_amount_edit_get_amount (GNC_AMOUNT_EDIT (pw->amount_debit_edit));
     amount_cred = gnc_amount_edit_get_amount (GNC_AMOUNT_EDIT (pw->amount_credit_edit));
     amount_tot = gnc_numeric_sub (amount_cred, amount_deb,
-            gnc_commodity_get_fraction (xaccAccountGetCommodity (pw->post_acct)),
-            GNC_HOW_RND_ROUND_HALF_UP);
+                                  gnc_commodity_get_fraction (xaccAccountGetCommodity (pw->post_acct)),
+                                  GNC_HOW_RND_ROUND_HALF_UP);
 
     if (gnc_numeric_check (amount_tot) || gnc_numeric_zero_p (amount_tot))
     {
@@ -595,6 +598,7 @@ gnc_payment_ok_cb (GtkWidget *widget, gpointer data)
         gnc_numeric exch = gnc_numeric_create(1, 1); //default to "one to one" rate
         GList *selected_lots = NULL;
         GtkTreeSelection *selection;
+        gboolean auto_pay;
 
         /* Obtain all our ancillary information */
         memo = gtk_entry_get_text (GTK_ENTRY (pw->memo_entry));
@@ -630,8 +634,13 @@ gnc_payment_ok_cb (GtkWidget *widget, gpointer data)
         }
 
         /* Perform the payment */
+        if (gncOwnerGetType (&(pw->owner)) == GNC_OWNER_CUSTOMER)
+            auto_pay = gnc_prefs_get_bool (GNC_PREFS_GROUP_INVOICE, GNC_PREF_AUTO_PAY);
+        else
+            auto_pay = gnc_prefs_get_bool (GNC_PREFS_GROUP_BILL, GNC_PREF_AUTO_PAY);
+
         gncOwnerApplyPayment (&pw->owner, pw->pre_existing_txn, selected_lots,
-                              post, acc, amount_tot, exch, date, memo, num);
+                              post, acc, amount_tot, exch, date, memo, num, auto_pay);
     }
     gnc_resume_gui_refresh ();
 
@@ -693,7 +702,7 @@ gnc_payment_acct_tree_row_activated_cb (GtkWidget *widget, GtkTreePath *path,
 
 void
 gnc_payment_leave_amount_cb (GtkWidget *widget, GdkEventFocus *event,
-        PaymentWindow *pw)
+                             PaymentWindow *pw)
 {
     gnc_numeric amount_deb, amount_cred, amount_tot;
 
@@ -704,8 +713,8 @@ gnc_payment_leave_amount_cb (GtkWidget *widget, GdkEventFocus *event,
     amount_deb  = gnc_amount_edit_get_amount (GNC_AMOUNT_EDIT (pw->amount_debit_edit));
     amount_cred = gnc_amount_edit_get_amount (GNC_AMOUNT_EDIT (pw->amount_credit_edit));
     amount_tot = gnc_numeric_sub (amount_cred, amount_deb,
-            gnc_commodity_get_fraction (xaccAccountGetCommodity (pw->post_acct)),
-            GNC_HOW_RND_ROUND_HALF_UP);
+                                  gnc_commodity_get_fraction (xaccAccountGetCommodity (pw->post_acct)),
+                                  GNC_HOW_RND_ROUND_HALF_UP);
 
     gnc_ui_payment_window_set_amount (pw, amount_tot);
 }
@@ -745,6 +754,27 @@ find_handler (gpointer find_data, gpointer user_data)
     return (pw != NULL);
 }
 
+static void print_date (GtkTreeViewColumn *tree_column,
+                        GtkCellRenderer *cell,
+                        GtkTreeModel *tree_model,
+                        GtkTreeIter *iter,
+                        gpointer data)
+{
+    GValue value = { 0 };
+    time64 doc_date_time;
+    gchar *doc_date_str;
+
+    g_return_if_fail (cell && iter && tree_model);
+
+
+    gtk_tree_model_get_value (tree_model, iter, 0, &value);
+    doc_date_time = (time64) g_value_get_int64 (&value);
+    g_value_unset (&value);
+    doc_date_str = qof_print_date (doc_date_time);
+    g_object_set (G_OBJECT (cell), "text", doc_date_str, NULL);
+    g_free (doc_date_str);
+}
+
 static PaymentWindow *
 new_payment_window (GncOwner *owner, QofBook *book, GncInvoice *invoice)
 {
@@ -752,6 +782,8 @@ new_payment_window (GncOwner *owner, QofBook *book, GncInvoice *invoice)
     GtkBuilder *builder;
     GtkWidget *box, *label, *credit_box, *debit_box;
     GtkTreeSelection *selection;
+    GtkTreeViewColumn *column;
+    GtkCellRenderer *renderer;
     char * cm_class = (gncOwnerGetType (owner) == GNC_OWNER_CUSTOMER ?
                        DIALOG_PAYMENT_CUSTOMER_CM_CLASS :
                        DIALOG_PAYMENT_VENDOR_CM_CLASS);
@@ -855,6 +887,41 @@ new_payment_window (GncOwner *owner, QofBook *book, GncInvoice *invoice)
     selection = gtk_tree_view_get_selection (GTK_TREE_VIEW(pw->docs_list_tree_view));
     gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
 
+    /* Configure date column */
+    renderer = gtk_cell_renderer_text_new ();
+    column = gtk_tree_view_get_column (GTK_TREE_VIEW (pw->docs_list_tree_view), 0);
+    gtk_tree_view_column_pack_start (column, renderer, TRUE);
+    tree_view_column_set_default_width (GTK_TREE_VIEW (pw->docs_list_tree_view),
+                                        column, "31-12-2013");
+    gtk_tree_view_column_set_cell_data_func (column, renderer,
+                                             (GtkTreeCellDataFunc) print_date,
+                                             NULL, NULL);
+
+    /* Configure document number column */
+    column = gtk_tree_view_get_column (GTK_TREE_VIEW (pw->docs_list_tree_view), 1);
+    tree_view_column_set_default_width (GTK_TREE_VIEW (pw->docs_list_tree_view),
+                                        column, "INV2013-016");
+
+    /* Configure document type column */
+    column = gtk_tree_view_get_column (GTK_TREE_VIEW (pw->docs_list_tree_view), 2);
+    tree_view_column_set_default_width (GTK_TREE_VIEW (pw->docs_list_tree_view),
+                                        column, _("Credit Note"));
+
+    /* Configure debit column */
+    column = gtk_tree_view_get_column (GTK_TREE_VIEW (pw->docs_list_tree_view), 3);
+    tree_view_column_set_default_width (GTK_TREE_VIEW (pw->docs_list_tree_view),
+                                        column, "11,999.00");
+
+    /* Configure credit column */
+    column = gtk_tree_view_get_column (GTK_TREE_VIEW (pw->docs_list_tree_view), 4);
+    tree_view_column_set_default_width (GTK_TREE_VIEW (pw->docs_list_tree_view),
+                                        column, "11,999.00");
+
+    gtk_tree_sortable_set_sort_column_id (
+        GTK_TREE_SORTABLE (gtk_tree_view_get_model (GTK_TREE_VIEW (pw->docs_list_tree_view))),
+        0, GTK_SORT_ASCENDING);
+
+
     box = GTK_WIDGET (gtk_builder_get_object (builder, "acct_window"));
     pw->acct_tree = GTK_WIDGET(gnc_tree_view_account_new (FALSE));
     gtk_container_add (GTK_CONTAINER (box), pw->acct_tree);
