@@ -28,7 +28,7 @@
 #include "gnc-ui-util.h"
 #include "gnc-component-manager.h"
 #include "gnc-event.h"
-#include "gnc-gconf-utils.h"
+#include "gnc-prefs.h"
 
 #include "gncEntry.h"
 #include "gncEntryLedger.h"
@@ -73,19 +73,19 @@ gnc_entry_ledger_refresh_internal (GncEntryLedger *ledger, GList *entries)
 }
 
 static void
-gnc_entry_ledger_gconf_changed (GConfEntry *entry, gpointer user_data)
+gnc_entry_ledger_pref_changed (gpointer prefs, gchar *pref, gpointer user_data)
 {
     GncEntryLedger *ledger = user_data;
 
-    g_return_if_fail (ledger && entry && entry->key);
+    g_return_if_fail (ledger && pref);
 
-    if (g_str_has_suffix (entry->key, KEY_ACCOUNT_SEPARATOR))
+    if (g_str_has_suffix (pref, GNC_PREF_ACCOUNT_SEPARATOR))
     {
         gnc_entry_ledger_display_refresh (ledger);
     }
     else
     {
-        g_warning ("gnc_entry_gconf_changed: Unknown gconf key %s", entry->key);
+        g_warning ("gnc_entry_ledger_pref_changed: Unknown preference %s", pref);
     }
 }
 
@@ -182,8 +182,8 @@ gnc_entry_ledger_display_init (GncEntryLedger *ledger)
     ledger->component_id = gnc_register_gui_component (ENTRYLEDGER_CLASS,
                            refresh_handler,
                            NULL, ledger);
-    gnc_gconf_general_register_cb(KEY_ACCOUNT_SEPARATOR,
-                                  gnc_entry_ledger_gconf_changed, ledger);
+    gnc_prefs_register_cb (GNC_PREFS_GROUP_GENERAL, GNC_PREF_ACCOUNT_SEPARATOR,
+                           gnc_entry_ledger_pref_changed, ledger);
 
     gnc_entry_ledger_display_refresh (ledger);
 }
@@ -194,8 +194,8 @@ gnc_entry_ledger_display_fini (GncEntryLedger *ledger)
     if (!ledger) return;
 
     gnc_unregister_gui_component (ledger->component_id);
-    gnc_gconf_general_remove_cb(KEY_ACCOUNT_SEPARATOR,
-                                gnc_entry_ledger_gconf_changed, ledger);
+    gnc_prefs_remove_cb_by_func (GNC_PREFS_GROUP_GENERAL, GNC_PREF_ACCOUNT_SEPARATOR,
+                                 gnc_entry_ledger_pref_changed, ledger);
 }
 
 void
