@@ -11,14 +11,14 @@
 (cond-expand
   (guile-2
     (eval-when
-      (compile load eval) 
+      (compile load eval expand)
       (load-extension "libgnc-core-utils" "scm_init_sw_core_utils_module")))
   (else
     (load-extension "libgnc-core-utils" "scm_init_sw_core_utils_module")))
 
 (use-modules (sw_core_utils))
 
-(re-export gnc-core-prefs-is-debugging-enabled)
+(re-export gnc-prefs-is-debugging-enabled)
 (re-export gnc-path-get-bindir)
 (re-export gnc-path-get-stdreportsdir)
 (re-export gnc-path-find-localized-html-file)
@@ -34,3 +34,12 @@
 (re-export gnc-scm-log-msg)
 (re-export gnc-scm-log-debug)
 (re-export gnc-locale-default-iso-currency-code)
+
+(re-export gnc-prefs-set-bool)
+(re-export gnc-prefs-set-int)
+(re-export gnc-prefs-set-int64)
+(re-export gnc-prefs-set-float)
+(re-export gnc-prefs-set-string)
+(re-export gnc-prefs-set-coords)
+
+(define-public gnc:version (gnc-version))
