@@ -177,6 +177,7 @@ const char *void_reason_str = "void-reason";
 const char *void_time_str = "void-time";
 const char *void_former_notes_str = "void-former-notes";
 const char *trans_is_closing_str = "book_closing";
+const char *assoc_uri_str = "assoc_uri";
 
 /* KVP entry for date-due value */
 #define TRANS_DATE_DUE_KVP       "trans-date-due"
@@ -289,6 +290,12 @@ gnc_transaction_finalize(GObject* txnp)
     G_OBJECT_CLASS(gnc_transaction_parent_class)->finalize(txnp);
 }
 
+/* Note that g_value_set_object() refs the object, as does
+ * g_object_get(). But g_object_get() only unrefs once when it disgorges
+ * the object, leaving an unbalanced ref, which leaks. So instead of
+ * using g_value_set_object(), use g_value_take_object() which doesn't
+ * ref the object when used in get_property().
+ */
 static void
 gnc_transaction_get_property(GObject* object,
                              guint prop_id,
@@ -309,7 +316,7 @@ gnc_transaction_get_property(GObject* object,
         g_value_set_string(value, tx->description);
         break;
     case PROP_CURRENCY:
-        g_value_set_object(value, tx->common_currency);
+        g_value_take_object(value, tx->common_currency);
         break;
     case PROP_POST_DATE:
         g_value_set_boxed(value, &tx->date_posted);
@@ -1047,7 +1054,8 @@ xaccTransIsBalanced (const Transaction *trans)
            the other. */
         FOR_EACH_SPLIT(trans, 
         {
-            if (xaccAccountGetType(xaccSplitGetAccount(s)) != ACCT_TYPE_TRADING)
+            Account *acc = xaccSplitGetAccount(s);
+            if (!acc || xaccAccountGetType(acc) != ACCT_TYPE_TRADING)
             {
                 imbal = gnc_numeric_add(imbal, xaccSplitGetValue(s),
                                         GNC_DENOM_AUTO, GNC_HOW_DENOM_EXACT);
@@ -1791,8 +1799,9 @@ xaccTransSetDateInternal(Transaction *trans, Timespec *dadate, Timespec val)
     {
         time64 secs = (time64) val.tv_sec;
         gchar *tstr = gnc_ctime (&secs);
-        PINFO ("addr=%p set date to %" G_GUINT64_FORMAT ".%09ld %s",
+        PINFO ("addr=%p set date to %" G_GUINT64_FORMAT ".%09ld %s\n",
                trans, val.tv_sec, val.tv_nsec, tstr ? tstr : "(null)");
+        g_free(tstr);
     }
 
     *dadate = val;
@@ -1849,6 +1858,7 @@ xaccTransSetDatePostedGDate (Transaction *trans, GDate date)
         kvp_value_delete(kvp_value);
     }
 
+    /* mark dirty and commit handled by SetDateInternal */
     xaccTransSetDateInternal(trans, &trans->date_posted,
                              gdate_to_timespec(date));
     set_gains_date_dirty (trans);
@@ -1999,6 +2009,17 @@ xaccTransSetDescription (Transaction *trans, const char *desc)
     xaccTransCommitEdit(trans);
 }
 
+void
+xaccTransSetAssociation (Transaction *trans, const char *assoc)
+{
+    if (!trans || !assoc) return;
+    xaccTransBeginEdit(trans);
+
+    kvp_frame_set_str (trans->inst.kvp_data, assoc_uri_str, assoc);
+    qof_instance_set_dirty(QOF_INSTANCE(trans));
+    xaccTransCommitEdit(trans);
+}
+
 static void
 qofTransSetNotes (Transaction *trans, const char *notes)
 {
@@ -2082,6 +2103,13 @@ xaccTransGetDescription (const Transaction *trans)
     return trans ? trans->description : NULL;
 }
 
+const char *
+xaccTransGetAssociation (const Transaction *trans)
+{
+    return trans ?
+           kvp_frame_get_string (trans->inst.kvp_data, assoc_uri_str) : NULL;
+}
+
 const char *
 xaccTransGetNotes (const Transaction *trans)
 {
@@ -2454,13 +2482,13 @@ xaccTransReverse (Transaction *orig)
         xaccSplitSetAmount(s, gnc_numeric_neg(xaccSplitGetAmount(s)));
         xaccSplitSetValue(s, gnc_numeric_neg(xaccSplitGetValue(s)));
         xaccSplitSetReconcile(s, NREC);
-        qof_instance_set_dirty(QOF_INSTANCE(trans));
     });
 
     /* Now update the original with a pointer to the new one */
     kvp_val = kvp_value_new_guid(xaccTransGetGUID(trans));
     kvp_frame_set_slot_nc(orig->inst.kvp_data, TRANS_REVERSED_BY, kvp_val);
 
+    qof_instance_set_dirty(QOF_INSTANCE(trans));
     xaccTransCommitEdit(trans);
     return trans;
 }
@@ -2680,6 +2708,11 @@ gboolean xaccTransRegister (void)
             (QofAccessFunc)xaccTransGetNotes,
             (QofSetterFunc)qofTransSetNotes
         },
+        {
+            TRANS_ASSOCIATION, QOF_TYPE_STRING,
+            (QofAccessFunc)xaccTransGetAssociation,
+            (QofSetterFunc)xaccTransSetAssociation
+        },
         {
             TRANS_IS_CLOSING, QOF_TYPE_BOOLEAN,
             (QofAccessFunc)xaccTransGetIsClosingTxn, NULL
