@@ -507,6 +507,14 @@ gnc_budget_set_account_period_value(GncBudget *budget, const Account *account,
     gchar path[BUF_SIZE];
     gchar *bufend;
 
+    /* Watch out for an off-by-one error here:
+     * period_num starts from 0 while num_periods starts from 1 */
+    if (period_num >= GET_PRIVATE(budget)->num_periods)
+    {
+        PWARN("Period %i does not exist", period_num);
+        return;
+    }
+
     gnc_budget_begin_edit(budget);
     frame = qof_instance_get_slots(QOF_INSTANCE(budget));
     guid = xaccAccountGetGUID(account);
@@ -573,7 +581,7 @@ gnc_budget_get_period_start_date(const GncBudget *budget, guint period_num)
     Timespec ts;
     timespecFromTime64(
         &ts, recurrenceGetPeriodTime(&GET_PRIVATE(budget)->recurrence,
-				     period_num, FALSE));
+                                     period_num, FALSE));
     return ts;
 }
 
