@@ -35,7 +35,7 @@
 #include <regex.h>
 
 #include "gnc-commodity.h"
-#include "gnc-core-prefs.h"
+#include "gnc-prefs.h"
 
 static QofLogModule log_module = GNC_MOD_COMMODITY;
 
@@ -82,6 +82,9 @@ typedef struct CommodityPrivate
     /* the number of accounts using this commodity - this field is not
      * persisted */
     int       usage_count;
+
+    /* the default display_symbol, set in iso-4217-currencies at start-up */
+    const char * default_symbol;
 } CommodityPrivate;
 
 #define GET_PRIVATE(o) \
@@ -93,6 +96,7 @@ struct _GncCommodityClass
 };
 
 static void commodity_free(gnc_commodity * cm);
+static void gnc_commodity_set_default_symbol(gnc_commodity *, const char *);
 
 struct gnc_commodity_namespace_s
 {
@@ -626,7 +630,12 @@ gnc_commodity_finalize(GObject* comp)
 {
     G_OBJECT_CLASS(gnc_commodity_parent_class)->finalize(comp);
 }
-
+/* Note that g_value_set_object() refs the object, as does
+ * g_object_get(). But g_object_get() only unrefs once when it disgorges
+ * the object, leaving an unbalanced ref, which leaks. So instead of
+ * using g_value_set_object(), use g_value_take_object() which doesn't
+ * ref the object when used in get_property().
+ */
 static void
 gnc_commodity_get_property (GObject         *object,
                             guint            prop_id,
@@ -643,7 +652,7 @@ gnc_commodity_get_property (GObject         *object,
     switch (prop_id)
     {
     case PROP_NAMESPACE:
-        g_value_set_object(value, priv->namespace);
+        g_value_take_object(value, priv->namespace);
         break;
     case PROP_FULL_NAME:
         g_value_set_string(value, priv->fullname);
@@ -825,6 +834,14 @@ gnc_commodity_new(QofBook *book, const char * fullname,
 
     if ( namespace != NULL )
     {
+	/* Prevent setting anything except template in namespace template. */
+	if (g_strcmp0 (namespace, "template") == 0 &&
+	    g_strcmp0 (mnemonic, "template") != 0)
+	{
+	    PWARN("Converting commodity %s from namespace template to "
+		  "namespace User", mnemonic);
+	    namespace = "User";
+	}
         gnc_commodity_set_namespace(retval, namespace);
         if (gnc_commodity_namespace_is_iso(namespace))
         {
@@ -1122,6 +1139,21 @@ gnc_commodity_get_quote_tz(const gnc_commodity *cm)
     return GET_PRIVATE(cm)->quote_tz;
 }
 
+/********************************************************************
+ * gnc_commodity_get_user_symbol
+ ********************************************************************/
+
+const char*
+gnc_commodity_get_user_symbol(const gnc_commodity *cm)
+{
+    const char *str;
+    if (!cm) return NULL;
+    str = kvp_frame_get_string(cm->inst.kvp_data, "user_symbol");
+    if (str && *str)
+	return str;
+    return GET_PRIVATE(cm)->default_symbol;
+}
+
 /********************************************************************
  * gnc_commodity_set_mnemonic
  ********************************************************************/
@@ -1356,6 +1388,37 @@ gnc_commodity_set_quote_tz(gnc_commodity *cm, const char *tz)
     LEAVE(" ");
 }
 
+/********************************************************************
+ * gnc_commodity_set_user_symbol
+ ********************************************************************/
+
+void
+gnc_commodity_set_user_symbol(gnc_commodity * cm, const char * user_symbol)
+{
+    if (!cm) return;
+
+    ENTER ("(cm=%p, symbol=%s)", cm, user_symbol ? user_symbol : "(null)");
+
+    gnc_commodity_begin_edit(cm);
+    kvp_frame_set_string(cm->inst.kvp_data, "user_symbol", user_symbol);
+    mark_commodity_dirty(cm);
+    gnc_commodity_commit_edit(cm);
+
+    LEAVE(" ");
+}
+
+/********************************************************************
+ * gnc_commodity_set_default_symbol
+ * Not made visible in gnc-commodity.h, it is only called from
+ * iso-4217-currencies.c at startup.
+ ********************************************************************/
+void
+gnc_commodity_set_default_symbol(gnc_commodity * cm,
+				 const char * default_symbol)
+{
+    GET_PRIVATE(cm)->default_symbol = default_symbol;
+}
+
 /********************************************************************
  * gnc_commodity_increment_usage_count
  ********************************************************************/
@@ -1800,13 +1863,22 @@ gnc_commodity_table_insert(gnc_commodity_table * table,
                 }
             }
         }
-
         gnc_commodity_copy (c, comm);
         gnc_commodity_destroy (comm);
         LEAVE("found at %p", c);
         return c;
     }
 
+    /* Prevent setting anything except template in namespace template. */
+    if (g_strcmp0 (ns_name, "template") == 0 &&
+	g_strcmp0 (priv->mnemonic, "template") != 0)
+    {
+	PWARN("Converting commodity %s from namespace template to "
+	      "namespace User", priv->mnemonic);
+	gnc_commodity_set_namespace (comm, "User");
+	ns_name = "User";
+    }
+
     book = qof_instance_get_book (&comm->inst);
     nsp = gnc_commodity_table_add_namespace(table, ns_name, book);
 
@@ -2023,7 +2095,7 @@ gnc_commodity_table_get_quotable_commodities(const gnc_commodity_table * table)
     GList * nslist, * tmp;
     GList * l = NULL;
     regex_t pattern;
-    const char *expression = gnc_core_prefs_get_namespace_regexp();
+    const char *expression = gnc_prefs_get_namespace_regexp();
 
     ENTER("table=%p, expression=%s", table, expression);
     if (!table)
