@@ -768,11 +768,6 @@ void gncEntrySetOrder (GncEntry *entry, GncOrder *order)
     mark_entry (entry);
     gncEntryCommitEdit (entry);
 
-    /* Generate an event modifying the Order's end-owner */
-#if 0
-    qof_event_gen (gncOwnerGetEndGUID (gncOrderGetOwner (order)),
-                   QOF_EVENT_MODIFY, NULL);
-#endif
 }
 
 /* called from gncInvoice when we're added to the Invoice */
@@ -844,6 +839,7 @@ void gncEntryCopy (const GncEntry *src, GncEntry *dest, gboolean add_entry)
     }
 
     dest->values_dirty = TRUE;
+    mark_entry (dest);
     gncEntryCommitEdit (dest);
 }
 
@@ -1330,6 +1326,7 @@ gncEntryRecomputeValues (GncEntry *entry)
     /* Determine the commodity denominator */
     denom = get_entry_commodity_denom (entry);
 
+    gncEntryBeginEdit (entry);
     /* Compute the invoice values */
     gncEntryComputeValue (entry->quantity, entry->i_price,
                           (entry->i_taxable ? entry->i_tax_table : NULL),
@@ -1362,6 +1359,8 @@ gncEntryRecomputeValues (GncEntry *entry)
     entry->b_tax_value_rounded = gnc_numeric_convert (entry->b_tax_value, denom,
                                  GNC_HOW_RND_ROUND_HALF_UP);
     entry->values_dirty = FALSE;
+    mark_entry (entry);
+    gncEntryCommitEdit (entry);
 }
 
 /* The "Int" functions below are for internal use only.
