@@ -380,7 +380,7 @@ GncInvoice *gncInvoiceCopy (const GncInvoice *from)
 
     // Posted-date and the posted Txn is intentionally not copied; the
     // copy isn't "posted" but needs to be posted by the user.
-
+    mark_invoice (invoice);
     gncInvoiceCommitEdit(invoice);
 
     return invoice;
@@ -621,27 +621,50 @@ void gncInvoiceAddEntry (GncInvoice *invoice, GncEntry *entry)
     if (old == invoice) return;	/* I already own this one */
     if (old) gncInvoiceRemoveEntry (old, entry);
 
+    gncInvoiceBeginEdit (invoice);
     gncEntrySetInvoice (entry, invoice);
     invoice->entries = g_list_insert_sorted (invoice->entries, entry,
                        (GCompareFunc)gncEntryCompare);
     mark_invoice (invoice);
+    gncInvoiceCommitEdit (invoice);
 }
 
 void gncInvoiceRemoveEntry (GncInvoice *invoice, GncEntry *entry)
 {
     if (!invoice || !entry) return;
 
+    gncInvoiceBeginEdit (invoice);
     gncEntrySetInvoice (entry, NULL);
     invoice->entries = g_list_remove (invoice->entries, entry);
     mark_invoice (invoice);
+    gncInvoiceCommitEdit (invoice);
 }
 
 void gncInvoiceAddPrice (GncInvoice *invoice, GNCPrice *price)
 {
+    GList *node;
+    gnc_commodity *commodity;
+
     if (!invoice || !price) return;
 
+    /* Keep only one price per commodity per invoice
+     * So if a price was set previously remove it first */
+    node = g_list_first(invoice->prices);
+    commodity = gnc_price_get_commodity (price);
+    while (node != NULL)
+    {
+        GNCPrice *curr = (GNCPrice*)node->data;
+        if (gnc_commodity_equal (commodity, gnc_price_get_commodity (curr)))
+            break;
+        node = g_list_next (node);
+    }
+
+    gncInvoiceBeginEdit (invoice);
+    if (node)
+        invoice->prices = g_list_delete_link (invoice->prices, node);
     invoice->prices = g_list_prepend(invoice->prices, price);
     mark_invoice (invoice);
+    gncInvoiceCommitEdit (invoice);
 }
 
 void gncBillAddEntry (GncInvoice *bill, GncEntry *entry)
@@ -656,19 +679,23 @@ void gncBillAddEntry (GncInvoice *bill, GncEntry *entry)
     if (old == bill) return;	/* I already own this one */
     if (old) gncBillRemoveEntry (old, entry);
 
+    gncInvoiceBeginEdit (bill);
     gncEntrySetBill (entry, bill);
     bill->entries = g_list_insert_sorted (bill->entries, entry,
                                           (GCompareFunc)gncEntryCompare);
     mark_invoice (bill);
+    gncInvoiceCommitEdit (bill);
 }
 
 void gncBillRemoveEntry (GncInvoice *bill, GncEntry *entry)
 {
     if (!bill || !entry) return;
 
+    gncInvoiceBeginEdit (bill);
     gncEntrySetBill (entry, NULL);
     bill->entries = g_list_remove (bill->entries, entry);
     mark_invoice (bill);
+    gncInvoiceCommitEdit (bill);
 }
 
 void gncInvoiceSortEntries (GncInvoice *invoice)
@@ -676,7 +703,46 @@ void gncInvoiceSortEntries (GncInvoice *invoice)
     if (!invoice) return;
     invoice->entries = g_list_sort(invoice->entries,
                                    (GCompareFunc)gncEntryCompare);
+    gncInvoiceBeginEdit (invoice);
     mark_invoice(invoice);
+    gncInvoiceCommitEdit (invoice);
+}
+
+void gncInvoiceRemoveEntries (GncInvoice *invoice)
+{
+    GList *node;
+
+    if (!invoice) return;
+
+    for (node = invoice->entries; node; node = node->next)
+    {
+        GncEntry *entry = node->data;
+
+        switch (gncInvoiceGetOwnerType (invoice))
+        {
+        case GNC_OWNER_VENDOR:
+        case GNC_OWNER_EMPLOYEE:
+            // this is a vendor bill, or an expense voucher
+            gncBillRemoveEntry (invoice, entry);
+            break;
+        case GNC_OWNER_CUSTOMER:
+        default:
+            // this is an invoice
+            gncInvoiceRemoveEntry (invoice, entry);
+            break;
+        }
+
+        /* If the entry is no longer referenced by any document,
+         * remove it.
+         */
+        if (!(gncEntryGetInvoice (entry) ||
+              gncEntryGetBill (entry) ||
+              gncEntryGetOrder (entry)))
+        {
+            gncEntryBeginEdit (entry);
+            gncEntryDestroy (entry);
+        }
+    }
 }
 
 /* ================================================================== */
@@ -906,11 +972,9 @@ const char * gncInvoiceGetTypeString (const GncInvoice *invoice)
     case GNC_INVOICE_EMPL_INVOICE:
         return _("Expense");
     case GNC_INVOICE_CUST_CREDIT_NOTE:
-        return _("Customer Credit Note");
     case GNC_INVOICE_VEND_CREDIT_NOTE:
-        return _("Vendor Credit Note");
     case GNC_INVOICE_EMPL_CREDIT_NOTE:
-        return _("Employee Credit Note");
+        return _("Credit Note");
     default:
         PWARN("Unknown invoice type");
         return NULL;
@@ -1179,6 +1243,66 @@ gboolean gncInvoiceAmountPositive (const GncInvoice *invoice)
     }
 }
 
+GHashTable *gncInvoiceGetForeignCurrencies (const GncInvoice *invoice)
+{
+    EntryList *entries_iter;
+    gboolean is_cust_doc = (gncInvoiceGetOwnerType (invoice) == GNC_OWNER_CUSTOMER);
+    gboolean is_cn = gncInvoiceGetIsCreditNote (invoice);
+    GHashTable *amt_hash = g_hash_table_new_full (g_direct_hash, g_direct_equal,
+                                                  NULL, g_free);
+
+    for (entries_iter = invoice->entries; entries_iter != NULL; entries_iter = g_list_next(entries_iter))
+    {
+        GncEntry *entry = (GncEntry*)entries_iter->data;
+        Account *this_acc;
+        gnc_commodity *account_currency;
+        AccountValueList *tt_amts = NULL, *tt_iter;
+
+        /* Check entry's account currency */
+        this_acc = (is_cust_doc ? gncEntryGetInvAccount (entry) :
+                    gncEntryGetBillAccount (entry));
+        account_currency = xaccAccountGetCommodity (this_acc);
+
+        if (this_acc &&
+                !gnc_commodity_equal (gncInvoiceGetCurrency (invoice), account_currency))
+        {
+            gnc_numeric *curr_amt = (gnc_numeric*) g_hash_table_lookup (amt_hash, account_currency);
+            gnc_numeric *entry_amt = (gnc_numeric*) g_new0 (gnc_numeric, 1);
+            *entry_amt = gncEntryGetDocValue (entry, FALSE, is_cust_doc, is_cn);
+            if (curr_amt)
+                *entry_amt = gnc_numeric_add (*entry_amt, *curr_amt, GNC_DENOM_AUTO, GNC_HOW_RND_ROUND_HALF_UP);
+            g_hash_table_insert (amt_hash, account_currency, entry_amt);
+        }
+
+        /* Check currencies of each account in the tax table linked
+         * to the current entry */
+        tt_amts = gncEntryGetDocTaxValues (entry, is_cust_doc, is_cn);
+
+        if (!tt_amts)
+            continue;
+
+        for (tt_iter = tt_amts; tt_iter != NULL; tt_iter = g_list_next(tt_iter))
+        {
+            GncAccountValue *tt_amt_val = (GncAccountValue*)tt_iter->data;
+            Account *tt_acc = tt_amt_val->account;
+            gnc_commodity *tt_acc_currency = xaccAccountGetCommodity (tt_acc);
+
+            if (tt_acc &&
+                    !gnc_commodity_equal (gncInvoiceGetCurrency (invoice), tt_acc_currency))
+            {
+                gnc_numeric *curr_amt = (gnc_numeric*) g_hash_table_lookup (amt_hash, tt_acc_currency);
+                gnc_numeric *tt_acc_amt = (gnc_numeric*) g_new0 (gnc_numeric, 1);
+                *tt_acc_amt = tt_amt_val->value;
+                if (curr_amt)
+                    *tt_acc_amt = gnc_numeric_add (*tt_acc_amt, *curr_amt, GNC_DENOM_AUTO, GNC_HOW_RND_ROUND_HALF_UP);
+                g_hash_table_insert (amt_hash, tt_acc_currency, tt_acc_amt);
+            }
+        }
+        gncAccountValueDestroy (tt_amts);
+    }
+    return amt_hash;
+}
+
 static gboolean gncInvoicePostAddSplit (QofBook *book,
                                         Account *acc,
                                         Transaction *txn,
@@ -1248,7 +1372,8 @@ static gboolean gncInvoicePostAddSplit (QofBook *book,
 
 Transaction * gncInvoicePostToAccount (GncInvoice *invoice, Account *acc,
                                        Timespec *post_date, Timespec *due_date,
-                                       const char * memo, gboolean accumulatesplits)
+                                       const char * memo, gboolean accumulatesplits,
+                                       gboolean autopay)
 {
     Transaction *txn;
     QofBook *book;
@@ -1262,7 +1387,6 @@ Transaction * gncInvoicePostToAccount (GncInvoice *invoice, Account *acc,
     char *lot_title;
     Account *ccard_acct = NULL;
     const GncOwner *owner;
-    gboolean autopay = TRUE; /* FIXME this will have to become a user selectable option at some point */
 
     if (!invoice || !acc) return NULL;
 
@@ -1488,6 +1612,10 @@ Transaction * gncInvoicePostToAccount (GncInvoice *invoice, Account *acc,
     gncAccountValueDestroy (splitinfo);
 
     gnc_lot_commit_edit (lot);
+    /* Not strictly necessary, since it was done by the Set calls
+     * above, but good insurance. */
+    DEBUG("Committing Invoice %s", invoice->id);
+    mark_invoice (invoice);
     gncInvoiceCommitEdit (invoice);
 
     /* If requested, attempt to automatically apply open payments
