@@ -249,11 +249,11 @@ gnc_taxtable_get_property (GObject         *object,
         g_value_set_string(value, tt->name);
         break;
     case PROP_INVISIBLE:
-    	g_value_set_boolean(value, tt->invisible);
-    	break;
+        g_value_set_boolean(value, tt->invisible);
+        break;
     case PROP_REFCOUNT:
-    	g_value_set_uint64(value, tt->refcount);
-    	break;
+        g_value_set_uint64(value, tt->refcount);
+        break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
         break;
@@ -277,14 +277,14 @@ gnc_taxtable_set_property (GObject         *object,
         gncTaxTableSetName(tt, g_value_get_string(value));
         break;
     case PROP_INVISIBLE:
-    	if (g_value_get_boolean(value))
-    	{
+        if (g_value_get_boolean(value))
+        {
             gncTaxTableMakeInvisible(tt);
-    	}
-    	break;
+        }
+        break;
     case PROP_REFCOUNT:
-    	gncTaxTableSetRefcount(tt, g_value_get_uint64(value));
-    	break;
+        gncTaxTableSetRefcount(tt, g_value_get_uint64(value));
+        break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
         break;
@@ -499,6 +499,7 @@ void gncTaxTableSetParent (GncTaxTable *table, GncTaxTable *parent)
         gncTaxTableAddChild(parent, table);
     table->refcount = 0;
     gncTaxTableMakeInvisible (table);
+    mark_table (table);
     gncTaxTableCommitEdit (table);
 }
 
@@ -507,6 +508,7 @@ void gncTaxTableSetChild (GncTaxTable *table, GncTaxTable *child)
     if (!table) return;
     gncTaxTableBeginEdit (table);
     table->child = child;
+    mark_table (table);
     gncTaxTableCommitEdit (table);
 }
 
@@ -516,6 +518,7 @@ void gncTaxTableIncRef (GncTaxTable *table)
     if (table->parent || table->invisible) return;        /* children dont need refcounts */
     gncTaxTableBeginEdit (table);
     table->refcount++;
+    mark_table (table);
     gncTaxTableCommitEdit (table);
 }
 
@@ -523,16 +526,21 @@ void gncTaxTableDecRef (GncTaxTable *table)
 {
     if (!table) return;
     if (table->parent || table->invisible) return;        /* children dont need refcounts */
+    g_return_if_fail (table->refcount > 0);
     gncTaxTableBeginEdit (table);
     table->refcount--;
-    g_return_if_fail (table->refcount >= 0);
+    mark_table (table);
     gncTaxTableCommitEdit (table);
 }
 
 void gncTaxTableSetRefcount (GncTaxTable *table, gint64 refcount)
 {
     if (!table) return;
+    g_return_if_fail (refcount >= 0);
+    gncTaxTableBeginEdit (table);
     table->refcount = refcount;
+    mark_table (table);
+    gncTaxTableCommitEdit (table);
 }
 
 void gncTaxTableMakeInvisible (GncTaxTable *table)
